@@ -1,25 +1,15 @@
 import abc
-from contextlib import suppress
-from typing import Any, List, Set, Tuple
+from typing import Any, Set, Tuple
 
 from click import Command
 
-from gethash.script import gethashcli, script_main
+from ..hasher import HashContext
+from ..script import gethashcli, script_main
 
 __all__ = ["Backend"]
 
 
 class Backend(metaclass=abc.ABCMeta):
-    _registry: List["Backend"] = []
-
-    @classmethod
-    def register_backend(cls) -> None:
-        cls._registry.append(cls())
-
-    @classmethod
-    def list_backends(cls) -> List["Backend"]:
-        return cls._registry
-
     @property
     @abc.abstractmethod
     def algorithms_available(self) -> Set[str]:
@@ -27,12 +17,13 @@ class Backend(metaclass=abc.ABCMeta):
         available in the backend."""
 
     @abc.abstractmethod
-    def load_ctx(self, name: str) -> Any:
+    def load_ctx(self, name: str) -> HashContext:
         """Load context."""
 
     def load_cmd(self, name: str) -> Command:
         """Load command."""
 
+        # Check `name` before invoking `main` for fast failure.
         if name not in self.algorithms_available:
             raise ValueError(f"unkown algorithm {name!r}")
 
@@ -46,18 +37,3 @@ class Backend(metaclass=abc.ABCMeta):
             script_main(ctx, files, **kwargs)
 
         return main
-
-
-def _load_backend() -> None:
-    from .hashlib import HashlibBackend
-
-    HashlibBackend.register_backend()
-
-    # For optional cryptographic backend.
-    with suppress(ImportError):
-        from .pycryptodome import PyCryptodomeBackend
-
-        PyCryptodomeBackend.register_backend()
-
-
-_load_backend()
