@@ -1,6 +1,6 @@
 import glob
 import os
-from typing import AnyStr, Callable, Iterable, Iterator, List, Optional
+from typing import Any, AnyStr, Callable, Iterable, Iterator, List, Optional, Union
 
 from natsort import os_sort_keygen
 
@@ -58,7 +58,7 @@ def _get_glob(mode: int) -> Callable[..., Iterator]:
 
 def _path_filter(paths: Iterable[AnyStr], *, type: str) -> Iterator[AnyStr]:
     _check_str(type, "type")
-    pred: Callable[..., bool]
+    pred: Callable[[Union[str, bytes]], bool]
     if type == "a":
         pred = os.path.exists
     elif type == "d":
@@ -195,19 +195,21 @@ def glob_filters(
     yield from _path_filter(matched, type=type)
 
 
-def sorted_path(iterable: Iterable[str], *, key: Optional[Callable] = None, reverse: bool = False) -> List[str]:
+def sorted_path(
+    iterable: Iterable[AnyStr], *, key: Optional[Callable[[AnyStr], Any]] = None, reverse: bool = False
+) -> List[AnyStr]:
     """Sort a list of path strings the same as the underlying operating system.
 
     Parameters:
-        iterable (Iterable[str]):
+        iterable (Iterable[AnyStr]):
             A list of path strings.
-        key (Callable | None, default=None):
+        key (Callable[[AnyStr], Any] | None, default=None):
             The same parameter as :func:`sorted`.
         reverse (bool, default=False):
             The same parameter as :func:`sorted`.
 
     Returns:
-        List[str]:
+        List[AnyStr]:
             The sorted list of path strings.
     """
 
